==> mingw-w64-aws-sdk-cpp-1.9.311-1.src.tar.zst: aws-sdk-cpp-1.9.311/aws-cpp-sdk-servicecatalog/source/model/BatchDisassociateServiceActionFromProvisioningArtifactResult.cpp <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#include <aws/servicecatalog/model/BatchDisassociateServiceActionFromProvisioningArtifactResult.h>
#include <aws/core/utils/json/JsonSerializer.h>
#include <aws/core/AmazonWebServiceResult.h>
#include <aws/core/utils/StringUtils.h>
#include <aws/core/utils/UnreferencedParam.h>

#include <utility>

using namespace Aws::ServiceCatalog::Model;
using namespace Aws::Utils::Json;
using namespace Aws::Utils;
using namespace Aws;

BatchDisassociateServiceActionFromProvisioningArtifactResult::BatchDisassociateServiceActionFromProvisioningArtifactResult()
{
}

BatchDisassociateServiceActionFromProvisioningArtifactResult::BatchDisassociateServiceActionFromProvisioningArtifactResult(const Aws::AmazonWebServiceResult<JsonValue>& result)
{
  *this = result;
}

BatchDisassociateServiceActionFromProvisioningArtifactResult& BatchDisassociateServiceActionFromProvisioningArtifactResult::operator =(const Aws::AmazonWebServiceResult<JsonValue>& result)
{
  JsonView jsonValue = result.GetPayload().View();
  if(jsonValue.ValueExists("FailedServiceActionAssociations"))
  {
    Array<JsonView> failedServiceActionAssociationsJsonList = jsonValue.GetArray("FailedServiceActionAssociations");
    for(unsigned failedServiceActionAssociationsIndex = 0; failedServiceActionAssociationsIndex < failedServiceActionAssociationsJsonList.GetLength(); ++failedServiceActionAssociationsIndex)
    {
      m_failedServiceActionAssociations.push_back(failedServiceActionAssociationsJsonList[failedServiceActionAssociationsIndex].AsObject());
    }
  }



  return *this;
}

==> mingw-w64-aws-sdk-cpp-1.10.9-1.src.tar.zst: aws-sdk-cpp-1.10.9/aws-cpp-sdk-servicecatalog/source/model/BatchDisassociateServiceActionFromProvisioningArtifactResult.cpp <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#include <aws/servicecatalog/model/BatchDisassociateServiceActionFromProvisioningArtifactResult.h>
#include <aws/core/utils/json/JsonSerializer.h>
#include <aws/core/AmazonWebServiceResult.h>
#include <aws/core/utils/StringUtils.h>
#include <aws/core/utils/UnreferencedParam.h>

#include <utility>

using namespace Aws::ServiceCatalog::Model;
using namespace Aws::Utils::Json;
using namespace Aws::Utils;
using namespace Aws;

BatchDisassociateServiceActionFromProvisioningArtifactResult::BatchDisassociateServiceActionFromProvisioningArtifactResult()
{
}

BatchDisassociateServiceActionFromProvisioningArtifactResult::BatchDisassociateServiceActionFromProvisioningArtifactResult(const Aws::AmazonWebServiceResult<JsonValue>& result)
{
  *this = result;
}

BatchDisassociateServiceActionFromProvisioningArtifactResult& BatchDisassociateServiceActionFromProvisioningArtifactResult::operator =(const Aws::AmazonWebServiceResult<JsonValue>& result)
{
  JsonView jsonValue = result.GetPayload().View();
  if(jsonValue.ValueExists("FailedServiceActionAssociations"))
  {
    Aws::Utils::Array<JsonView> failedServiceActionAssociationsJsonList = jsonValue.GetArray("FailedServiceActionAssociations");
    for(unsigned failedServiceActionAssociationsIndex = 0; failedServiceActionAssociationsIndex < failedServiceActionAssociationsJsonList.GetLength(); ++failedServiceActionAssociationsIndex)
    {
      m_failedServiceActionAssociations.push_back(failedServiceActionAssociationsJsonList[failedServiceActionAssociationsIndex].AsObject());
    }
  }



  return *this;
}
